@@ -8,6 +8,7 @@
 #pragma once
 #include <vector>
 #include <map>
+#include <atomic>
 
 #include "ze_ddi.h"
 #include "zet_ddi.h"
@@ -21,7 +22,8 @@
 #include "zes_ldrddi.h"
 
 #include "loader/ze_loader.h"
-
+#include "logging.h"
+#include "spdlog/spdlog.h"
 namespace loader
 {
     //////////////////////////////////////////////////////////////////////////
@@ -30,6 +32,7 @@ namespace loader
         HMODULE handle = NULL;
         ze_result_t initStatus = ZE_RESULT_SUCCESS;
         dditable_t dditable = {};
+        std::string name;
     };
 
     using driver_vector_t = std::vector< driver_t >;
@@ -44,17 +47,23 @@ namespace loader
 
         HMODULE validationLayer = nullptr;
         HMODULE tracingLayer = nullptr;
+        bool driverEnvironmentQueried = false;
 
         bool forceIntercept = false;
         std::vector<zel_component_version_t> compVersions;
         const char *LOADER_COMP_NAME = "loader";
 
         ze_result_t check_drivers(ze_init_flags_t flags);
+        void debug_trace_message(std::string errorMessage, std::string errorValue);
         ze_result_t init();
         ze_result_t init_driver(driver_t driver, ze_init_flags_t flags);
         void add_loader_version();
         ~context_t();
         bool intercept_enabled = false;
+        bool debugTraceEnabled = false;
+        bool tracingLayerEnabled = false;
+        dditable_t tracing_dditable = {};
+        std::shared_ptr<Logger> zel_logger;
     };
 
     extern context_t *context;
